<html>
<head>
	<link rel="stylesheet" href="style/style.css" />
	<script type="text/javascript" src="js/jquery.js"></script>
	<script type="text/javascript" src="js/datatables.js"></script>
	
	<?php 
		require_once("config.php");
		require_once("query.php");
		require_once("blockdata.php");
		require_once("parseinput.php");
	?>
</head>

<?php 

// Global variables
$timeQuery = "";
$blocklistQuery = "";
$actionQuery = "";
$worldQuery = "";
$playerQuery = "";
$mobList = array("#creeper", "#ender", "#zombie", "#villager");
$envList = array("#lava", "#water", "#tnt", "#fire");

$con;
$inputs = array();
$resultArray = array();
$resultCount = 0;

// If successful post
if(isset($_POST['inputs'])){
	global $queryArray, $flags, $resultArray;
	
	$inputs = $_POST["inputs"];
	
	$resultCount = 0;
	$resultArray = array();
	
	connect();
	parseInput();
	
	$inputs = escapeArray($inputs);
	
	// Query blocks table
	if(array_key_exists('actions', $inputs)){
		$resultArray = array_merge(queryBlocksTable(), $resultArray);
	}
	
	// Query signs table
	if(array_key_exists('sp', $inputs) && $resultCount <= $MAXRESULTS){
		$resultArray = array_merge(querySignsTable(), $resultArray);
	}
	
	// Query containers table
	if(array_key_exists('ch', $inputs) && $resultCount <= $MAXRESULTS){
		$resultArray = array_merge(queryContainersTable(), $resultArray);
	}
	
	// Filter coords
	if(array_key_exists('x', $inputs) || array_key_exists('y', $inputs) || array_key_exists('z', $inputs)){
		filterCoords();
	}
	
	// Check for empty result array
	if(count($resultArray) == 0){
		showError("No results found");
	} else {
		printResults();
	}
	
	disconnect();
}


/*
 * Connect to MySQL
*/
function connect(){
	global $con;
	global $HOST, $USER, $PASS, $DATABASE, $PORT;

	@$con = new mysqli($HOST, $USER, $PASS, $DATABASE, $PORT);

	if ($con->connect_errno)
		showError("Failed to connect to MySQL: (" . $con->connect_errno . ") " . $con->connect_error);
}


/*
 * Disconnect from MySQL
*/
function disconnect(){
	global $con;
	mysqli_close($con);
}


/*
 * Takes in array, filters out coordinates outside of user's input, returns new array
 */
function filterCoords(){
	global $inputs, $DEFAULTRADIUS, $resultArray;

	$radius = $DEFAULTRADIUS;
	$minx = $miny = $minz = null;
	$maxx = $maxy = $maxz = null;
	
	if(array_key_exists('radius', $inputs)) $radius = $inputs['radius'];
	
	if(array_key_exists('x', $inputs)) {
		$minx = $inputs['x'] - $radius;
		$maxx = $inputs['x'] + $radius;
	}
	
	if(array_key_exists('y', $inputs)) {
		$miny = $inputs['y'] - $radius;
		$maxy = $inputs['y'] + $radius;
	}
	
	if(array_key_exists('z', $inputs)) {
		$minz = $inputs['z'] - $radius;
		$maxz = $inputs['z'] + $radius;
	}

	$tempArray = array();
	
	for($i = 0; $i < count($resultArray); $i++){
		if(isset($inputs['x']) && ($resultArray[$i]['x'] < $minx || $resultArray[$i]['x'] > $maxx)) continue;
		if(isset($inputs['y']) && ($resultArray[$i]['y'] < $miny || $resultArray[$i]['y'] > $maxy)) continue;
		if(isset($inputs['z']) && ($resultArray[$i]['z'] < $minz || $resultArray[$i]['z'] > $maxz)) continue;
		array_push($tempArray, $resultArray[$i]);
	}
	
	$resultArray = $tempArray;
}
	

/*
 * Escapes array
 */
function escapeArray($array){
	global $con;
	
	if(!is_array($array))
		return mysqli_real_escape_string($con, $array);
	
	foreach($array as $key=>$value){
		if(is_array($array[$key])){
			foreach($array[$key] as $subkey=>$subvalue){
				$array[$key][$subkey] = escapeArray($array[$key][$subkey]);
			}
		} else {
			$array[$key] = mysqli_real_escape_string($con, $array[$key]);
		}
	}
	
	return $array;
}


/*
 * Displays error and exits
 */
function showError($message){
	echo "<br><br><div class='container' id='errorContainer'><div class='header' id='errorHeader'>Error</div><div class='content' id='errorContent'>$message</div></div>";
	exit();
}

?>


<script>
function copyToClipboard(text) {
	window.prompt ("Copy to clipboard: Ctrl+C, Enter", text);
}
</script>


<body>
	<?php
	
	function printResults(){
		global $resultArray, $COMMAND;
		
		echo '
		<table id="resultsTable" class="resultsTable" style="visibility:hidden">
			<thead><tr>
					<th>Date/Time</th>
					<th>Player</th>
					<th>Action</th>
					<th>Data</th>
					<th>X</th>
					<th>Y</th>
					<th>Z</th>
					<th>World</th>
					<th></th>
				</tr></thead>
			<tbody>';
			
				foreach($resultArray as $result){	
					$coords = trim($COMMAND) . " " . $result['x'] . " " . $result['y'] . " " . $result['z'];
					echo '<tr class="tableRow"><td>' . date('M j, y, g:ia', $result['time']) .
						 '</td><td>' . $result['user'] .
						 '</td><td>' . $result['action'] .
						 '</td><td>' . $result['data'] .
						 '</td><td>' . $result['x'] .
						 '</td><td>' . $result['y'] .
						 '</td><td>' . $result['z'] .
						 '</td><td>' . $result['world'] .
						 '</td><td class="clipboard" coords="'.$coords.'">' .
					     '</td></tr>';
				}
			
		echo '</tbody></table>';
	}
	
	?>
</body>
</html>
